==> react-native-ui-xep-0.1.36.tgz: package/src/atoms/input/Input.tsx <==
import React, { FC } from 'react';
import {
  Icon,
  Input as InputX,
  Item,
  Label,
  NativeBase,
  RnViewStyleProp,
} from 'native-base';
import { styles } from './styles';
import {
  borderedInputVariables,
  primaryInputVariables,
} from '../../Configurations/ThemeConfig';

type Props = NativeBase.Input & {
  type?: 'material' | 'material-black' | 'primary' | 'bordered';
  inputStyle?: any;
  label?: string;
  style?: RnViewStyleProp;
  iconName?: string;
  iconProps?: NativeBase.Icon;
  labelProps?: NativeBase.Label;
  inputProps?: NativeBase.Input;
  validationInfo?: string[];
  shadow?: boolean;
  // children?: ReactNode;
};
export const Input: FC<Props> = (props: Props) => {
  const {
    type,
    label,
    labelProps,
    iconName,
    iconProps,
    style,
    inputStyle,
    shadow,
  } = props;
  const propsX = { ...props };
  propsX.style = inputStyle;
  delete propsX.labelProps;
  delete propsX.iconProps;
  delete propsX.type;
  delete propsX.label;
  delete propsX.inputStyle;

  const renderElement = (
    itemStyle?: any,
    inputStyleX?: any,
    labelStyle?: any,
    iconStyle?: any,
    placeholderTextColor?: string,
    inputWrapperStyle?: any
  ) => {
    inputStyleX = shadow ? { ...inputStyleX, ...styles.shadow } : inputStyleX;
    return (
      <Item
        stackedLabel={label !== undefined}
        underline
        style={
          style !== undefined
            ? { ...itemStyle, ...(style as object) }
            : itemStyle
        }
      >
        {label && (
          <Label
            {...labelProps}
            style={
              labelProps?.style
                ? { ...labelStyle, ...(labelProps.style as object) }
                : labelStyle
            }
          >
            {label}
            {/*{'   '}*/}
            {/*{validationInfo && validationInfo?.length > 0 && (*/}
            {/*  <Text style={{ color: '#f39c12', marginLeft: 5 }}>*/}
            {/*    {validationInfo}*/}
            {/*  </Text>*/}
            {/*)}*/}
          </Label>
        )}
        <Item
          style={[
            { ...inputWrapperStyle },
            { borderBottomWidth: 0, marginLeft: type === 'material' ? -4 : 0 },
          ]}
        >
          <InputX
            placeholderTextColor={placeholderTextColor ?? '#C4C4C4'}
            {...propsX}
            style={inputStyle ? { ...inputStyleX, ...inputStyle } : inputStyleX}
          />
          {iconName && (
            <Icon
              active
              {...iconProps}
              name={iconName}
              style={
                labelProps?.style
                  ? { ...iconStyle, ...(iconProps?.style as object) }
                  : iconStyle
              }
            />
          )}
        </Item>
      </Item>
    );
  };
  switch (type) {
    case 'material':
      return renderElement(
        styles.itemStyleMaterial,
        styles.material,
        {
          ...styles.textMaterial,
          color: primaryInputVariables.labelColor,
          fontSize: 17,
          // lineHeight: 20,
        },
        styles.iconWhite,
        primaryInputVariables.placeholderColor,
        styles.inputWrapper
      );
    case 'material-black':
      return renderElement(
        styles.itemStyleMaterialBlack,
        styles.materialBlack,
        { ...styles.textMaterial, color: 'black' },
        styles.iconDefault,
        undefined,
        styles.inputWrapperMB
      );
    case 'bordered':
      return renderElement(
        styles.itemStyle,
        { ...styles.bordered },
        {
          ...styles.textDefault,
          color: borderedInputVariables.labelColor,
          fontWeight: 'bold',
          marginLeft: 10,
        },
        undefined,
        borderedInputVariables.placeholderColor
      );
    default:
      return renderElement(
        styles.itemStyle,
        styles.default,
        styles.textDefault,
        undefined,
        primaryInputVariables.placeholderColor
      );
  }
};

==> react-native-ui-xep-0.1.38.tgz: package/src/atoms/input/Input.tsx <==
import React, { FC } from 'react';
import {
  Icon,
  Input as InputX,
  Item,
  Label,
  NativeBase,
  RnViewStyleProp,
} from 'native-base';
import { styles } from './styles';
import {
  borderedInputVariables,
  primaryInputVariables,
} from '../../Configurations/ThemeConfig';

type Props = NativeBase.Input & {
  type?: 'material' | 'material-black' | 'primary' | 'bordered';
  inputStyle?: any;
  label?: string;
  style?: RnViewStyleProp;
  iconName?: string;
  iconProps?: NativeBase.Icon;
  labelProps?: NativeBase.Label;
  inputProps?: NativeBase.Input;
  validationInfo?: string[];
  shadow?: boolean;
  // children?: ReactNode;
};
export const Input: FC<Props> = (props: Props) => {
  const {
    type,
    label,
    labelProps,
    iconName,
    iconProps,
    style,
    inputStyle,
    shadow,
  } = props;
  const propsX = { ...props };
  propsX.style = inputStyle;
  delete propsX.labelProps;
  delete propsX.iconProps;
  delete propsX.type;
  delete propsX.label;
  delete propsX.inputStyle;

  const renderElement = (
    itemStyle?: any,
    inputStyleX?: any,
    labelStyle?: any,
    iconStyle?: any,
    placeholderTextColor?: string,
    inputWrapperStyle?: any
  ) => {
    inputStyleX = shadow ? { ...inputStyleX, ...styles.shadow } : inputStyleX;
    return (
      <Item
        stackedLabel={label !== undefined}
        underline
        style={
          style !== undefined
            ? { ...itemStyle, ...(style as object) }
            : itemStyle
        }
      >
        {label && (
          <Label
            {...labelProps}
            style={
              labelProps?.style
                ? { ...labelStyle, ...(labelProps.style as object) }
                : labelStyle
            }
          >
            {label}
            {/*{'   '}*/}
            {/*{validationInfo && validationInfo?.length > 0 && (*/}
            {/*  <Text style={{ color: '#f39c12', marginLeft: 5 }}>*/}
            {/*    {validationInfo}*/}
            {/*  </Text>*/}
            {/*)}*/}
          </Label>
        )}
        <Item
          style={[
            { ...inputWrapperStyle },
            { marginLeft: type === 'material' ? -4 : 0 },
          ]}
        >
          <InputX
            placeholderTextColor={placeholderTextColor ?? '#C4C4C4'}
            {...propsX}
            style={inputStyle ? { ...inputStyleX, ...inputStyle } : inputStyleX}
          />
          {iconName && (
            <Icon
              active
              {...iconProps}
              name={iconName}
              style={
                iconProps?.style
                  ? { ...iconStyle, ...(iconProps?.style as object) }
                  : iconStyle
              }
            />
          )}
        </Item>
      </Item>
    );
  };
  switch (type) {
    case 'material':
      return renderElement(
        styles.itemStyleMaterial,
        styles.material,
        {
          ...styles.textMaterial,
          color: primaryInputVariables.labelColor,
          fontSize: 17,
          // lineHeight: 20,
        },
        styles.iconWhite,
        primaryInputVariables.placeholderColor,
        styles.inputWrapper
      );
    case 'material-black':
      return renderElement(
        styles.itemStyleMaterialBlack,
        styles.materialBlack,
        { ...styles.textMaterial, color: 'black' },
        styles.iconDefault,
        undefined,
        styles.inputWrapperMB
      );
    case 'bordered':
      return renderElement(
        styles.itemStyle,
        { ...styles.bordered },
        {
          ...styles.textDefault,
          color: borderedInputVariables.labelColor,
          fontWeight: 'bold',
          marginLeft: 10,
        },
        undefined,
        borderedInputVariables.placeholderColor
      );
    default:
      return renderElement(
        styles.itemStyle,
        styles.default,
        styles.textDefault,
        undefined,
        primaryInputVariables.placeholderColor
      );
  }
};
